@@ -6,6 +6,8 @@ import requests
 
 from scratchconnect import Exceptions
 from scratchconnect import CloudConnection
+from scratchconnect import TurbowarpCloudConnection
+from scratchconnect import scCloudStorage
 
 _website = "scratch.mit.edu"
 _login = f"https://{_website}/login/"
@@ -14,11 +16,12 @@ _project = f"https://{_api}/projects/"
 
 
 class Project:
-    def __init__(self, id, client_username, csrf_token, session_id, token):
+    def __init__(self, id, client_username, csrf_token, session_id, token, unshared):
         """
         The Project Class
         :param id: The project ID
         """
+        self.access_unshared = unshared
         self.project_id = str(id)
         self.client_username = client_username
         self.csrf_token = csrf_token
@@ -69,19 +72,23 @@ class Project:
         try:
             self.project_id = data["id"]
         except KeyError:
-            raise Exceptions.InvalidProject(f"The project with ID - '{self.project_id}' doesn't exist!")
-        self.project_author = data["author"]
-        self.project_title = data["title"]
-        self.project_notes = data["description"]
-        self.project_instructions = data["instructions"]
-        self.project_are_comments_allowed = data["comments_allowed"] == True
-        self.project_stats = data["stats"]
-        self.project_history = data["history"]
-        self.project_remix_data = data["remix"]
-        self.project_visibility = data["visibility"]
-        self.project_is_public = data["public"] == True
-        self.project_is_published = data["is_published"] == True
-        self.project_thubmnail_url = data["images"]
+            if self.access_unshared:
+                pass
+            else:
+                raise Exceptions.InvalidProject(f"The project with ID - '{self.project_id}' doesn't exist!")
+        if not self.access_unshared:
+            self.project_author = data["author"]
+            self.project_title = data["title"]
+            self.project_notes = data["description"]
+            self.project_instructions = data["instructions"]
+            self.project_are_comments_allowed = data["comments_allowed"] == True
+            self.project_stats = data["stats"]
+            self.project_history = data["history"]
+            self.project_remix_data = data["remix"]
+            self.project_visibility = data["visibility"]
+            self.project_is_public = data["public"] == True
+            self.project_is_published = data["is_published"] == True
+            self.project_thubmnail_url = data["images"]
 
     def id(self):
         """
@@ -453,3 +460,23 @@ class Project:
         return CloudConnection.CloudConnection(project_id=self.project_id, client_username=self.client_username,
                                                csrf_token=self.csrf_token,
                                                session_id=self.session_id, token=self.token)
+
+    def connect_turbowarp_cloud(self, username=None):
+        """
+        Connect the cloud variables of the project
+        """
+        if username is None:
+            username = self.client_username
+        return TurbowarpCloudConnection.TurbowarpCloudConnection(project_id=self.project_id,
+                                                                 username=username)
+
+    def create_cloud_storage(self, file_name="data", rewrite_file=True, edit_access=None):
+        """
+        Create a Cloud Database in a project
+        """
+        if edit_access is None:
+            edit_access = []
+        return scCloudStorage.CloudStorage(file_name=file_name, rewrite_file=rewrite_file, project_id=self.project_id,
+                                           client_username=self.client_username,
+                                           csrf_token=self.csrf_token,
+                                           session_id=self.session_id, token=self.token, edit_access=edit_access)
